@@ -2,18 +2,18 @@
 #define SYNCTHING_TRAY_APP_H
 
 #include "./appbase.h"
+#include "./quickicon.h"
 
 #ifdef Q_OS_ANDROID
 #include "./android.h"
 #endif
 
-#include <syncthingwidgets/misc/diffhighlighter.h>
-#include <syncthingwidgets/misc/internalerror.h>
-#include <syncthingwidgets/misc/otherdialogs.h>
-#include <syncthingwidgets/misc/statusinfo.h>
-#include <syncthingwidgets/misc/syncthinglauncher.h>
-#include <syncthingwidgets/misc/utils.h>
-#include <syncthingwidgets/quick/quickicon.h>
+#include "../misc/diffhighlighter.h"
+#include "../misc/internalerror.h"
+#include "../misc/otherdialogs.h"
+#include "../misc/statusinfo.h"
+#include "../misc/syncthinglauncher.h"
+#include "../misc/utils.h"
 
 #include <syncthingmodel/syncthingdevicemodel.h>
 #include <syncthingmodel/syncthingdirectorymodel.h>
@@ -23,6 +23,7 @@
 
 #include <qtutilities/settingsdialog/qtsettings.h>
 
+#include <QJSValue>
 #include <QJsonObject>
 #include <QQmlApplicationEngine>
 #include <QtVersion>
@@ -52,7 +53,7 @@ class SYNCTHINGWIDGETS_EXPORT App : public AppBase {
     Q_PROPERTY(bool darkmodeEnabled READ isDarkmodeEnabled NOTIFY darkmodeEnabledChanged)
     Q_PROPERTY(int iconSize READ iconSize CONSTANT)
     Q_PROPERTY(int iconWidthDelegate READ iconWidthDelegate CONSTANT)
-    Q_PROPERTY(bool nativePopups READ nativePopups CONSTANT)
+    Q_PROPERTY(bool windowPopups READ windowPopups CONSTANT)
     Q_PROPERTY(bool extendedClientArea READ extendedClientArea CONSTANT)
     Q_PROPERTY(QString syncthingVersion READ syncthingVersion CONSTANT)
     Q_PROPERTY(QString qtVersion READ qtVersion CONSTANT)
@@ -80,6 +81,8 @@ class SYNCTHINGWIDGETS_EXPORT App : public AppBase {
     Q_PROPERTY(QFont font READ font CONSTANT)
     Q_PROPERTY(bool storagePermissionGranted READ storagePermissionGranted NOTIFY storagePermissionGrantedChanged)
     Q_PROPERTY(bool notificationPermissionGranted READ notificationPermissionGranted NOTIFY notificationPermissionGrantedChanged)
+    Q_PROPERTY(QString currentSyncthingHomeDir READ currentSyncthingHomeDir)
+    Q_PROPERTY(QString closePreference READ closePreference)
     Q_PROPERTY(QObject *currentDialog READ currentDialog)
     QML_ELEMENT
     QML_SINGLETON
@@ -127,13 +130,13 @@ public:
         storeSettings();
         emit settingsChanged(m_settings);
     }
-#if defined(Q_OS_ANDROID) || defined(Q_OS_WINDOWS) // it leads to crashes on those platforms
-    static constexpr bool nativePopups()
+#if defined(Q_OS_ANDROID)
+    static constexpr bool windowPopups()
     {
         return false;
     }
 #else
-    bool nativePopups() const;
+    bool windowPopups() const;
 #endif
     static constexpr bool extendedClientArea()
     {
@@ -279,6 +282,7 @@ public:
     bool notificationPermissionGranted() const;
     QString currentSyncthingHomeDir() const;
     QObject *currentDialog();
+    const QString &closePreference();
 
     // helper functions
     Q_INVOKABLE bool initEngine();
@@ -299,12 +303,12 @@ public:
     Q_INVOKABLE bool openSyncthingConfigFile();
     Q_INVOKABLE bool openSyncthingLogFile();
     Q_INVOKABLE bool openUrlExternally(const QUrl &url, bool viaQt = false);
-    Q_INVOKABLE bool checkSettings(const QUrl &url, const QJSValue &callback = QJSValue());
-    Q_INVOKABLE bool importSettings(const QVariantMap &availableSettings, const QVariantMap &selectedSettings, const QJSValue &callback = QJSValue());
-    Q_INVOKABLE bool exportSettings(const QUrl &url, const QJSValue &callback = QJSValue());
+    Q_INVOKABLE bool checkSettings(QUrl url, const QJSValue &callback = QJSValue());
+    Q_INVOKABLE bool importSettings(QVariantMap availableSettings, QVariantMap selectedSettings, const QJSValue &callback = QJSValue());
+    Q_INVOKABLE bool exportSettings(QUrl url, const QJSValue &callback = QJSValue());
     Q_INVOKABLE bool checkSyncthingHome(const QJSValue &callback = QJSValue());
-    Q_INVOKABLE bool moveSyncthingHome(const QString &newHomeDir, const QJSValue &callback = QJSValue());
-    Q_INVOKABLE bool saveSupportBundle(const QUrl &url, const QJSValue &callback = QJSValue());
+    Q_INVOKABLE bool moveSyncthingHome(QString newHomeDir, const QJSValue &callback = QJSValue());
+    Q_INVOKABLE bool saveSupportBundle(QUrl url, const QJSValue &callback = QJSValue());
     Q_INVOKABLE bool openPath(const QString &path);
     Q_INVOKABLE bool openPath(const QString &dirId, const QString &relativePath);
     Q_INVOKABLE bool scanPath(const QString &path);
@@ -436,10 +440,23 @@ private:
     mutable std::optional<bool> m_storagePermissionGranted;
     mutable std::optional<bool> m_notificationPermissionGranted;
 #endif
-    std::pair<QVariantMap, QVariantMap> m_settingsImport;
-    std::optional<QUrl> m_settingsExport;
-    std::optional<QFile> m_downloadFile;
-    std::optional<QString> m_homeDirMove;
+    struct {
+        QVariantMap availableSettings;
+        QVariantMap selectedSettings;
+        QJSValue callback;
+    } m_settingsImport;
+    struct {
+        std::optional<QUrl> url;
+        QJSValue callback;
+    } m_settingsExport;
+    struct {
+        std::optional<QFile> outputFile;
+    } m_download;
+    struct {
+        std::optional<QString> newHomeDir;
+        QJSValue callback;
+    } m_homeDirMove;
+    std::optional<QString> m_closePreference;
     QtUtilities::QtSettings m_qtSettings;
     QString m_faUrlBase;
     std::array<QObject *, 5> m_uiObjects;
