@@ -13,7 +13,6 @@
 #include <c++utilities/io/ansiescapecodes.h>
 
 #include <QAuthenticator>
-#include <QDir>
 #include <QFileInfo>
 #include <QHostAddress>
 #include <QJsonArray>
@@ -22,6 +21,7 @@
 #include <QNetworkAccessManager>
 #include <QNetworkInterface>
 #include <QNetworkReply>
+#include <QStandardPaths>
 #include <QStringBuilder>
 #include <QTimer>
 
@@ -119,6 +119,7 @@ SyncthingConnection::SyncthingConnection(
     , m_recordFileChanges(false)
     , m_useDeprecatedRoutes(true)
     , m_pausingOnMeteredConnection(false)
+    , m_forceSuspend(false)
 #ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
     , m_handlingMeteredConnectionInitialized(false)
 #endif
@@ -364,25 +365,41 @@ void SyncthingConnection::disablePolling()
 }
 
 /*!
- * \brief Sets whether to pause all devices on metered connections.
+ * \brief Sets whether to pause all devices, discovery and relaying on metered connections.
+ * \remark This is realized by calling the function suspendOrResume() which can also be called manually
+ *         to temporarily override this.
  */
-void SyncthingConnection::setPausingOnMeteredConnection(bool pausingOnMeteredConnection)
+bool SyncthingConnection::setPausingOnMeteredConnection(bool pausingOnMeteredConnection, bool lazy)
 {
-    if (m_pausingOnMeteredConnection != pausingOnMeteredConnection) {
-        if ((m_pausingOnMeteredConnection = pausingOnMeteredConnection)) {
-            // initialize handling of metered connections
-#ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
-            if (!m_handlingMeteredConnectionInitialized) {
-                if (const auto [networkInformation, isMetered] = loadNetworkInformationBackendForMetered(); networkInformation) {
-                    QObject::connect(networkInformation, &QNetworkInformation::isMeteredChanged, this, &SyncthingConnection::handleMeteredConnection);
-                }
-            }
-#endif
-        }
-        if (m_hasConfig) {
-            handleMeteredConnection();
-        }
+    if (m_pausingOnMeteredConnection == pausingOnMeteredConnection) {
+        return false;
     }
+    if ((m_pausingOnMeteredConnection = pausingOnMeteredConnection)) {
+        // initialize handling of metered connections
+#ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
+        if (!m_forceSuspend && !m_handlingMeteredConnectionInitialized) {
+            if (const auto [networkInformation, isMetered] = loadNetworkInformationBackendForMetered(); networkInformation) {
+                QObject::connect(networkInformation, &QNetworkInformation::isMeteredChanged, this, &SyncthingConnection::handleMeteredConnection);
+                return lazy || suspendOrResume(isMetered);
+            }
+        }
+#endif
+    }
+    return lazy || handleMeteredConnection();
+}
+
+/*!
+ * \brief Sets whether to pause all devices, discovery and relaying.
+ * \remark This is realized by calling the function suspendOrResume() which can also be called manually
+ *         to suspend only temporarily.
+ */
+bool SyncthingConnection::setForceSuspendEnabled(bool forceSuspendEnabled, bool lazy)
+{
+    if (m_forceSuspend == forceSuspendEnabled) {
+        return false;
+    }
+    m_forceSuspend = forceSuspendEnabled;
+    return lazy || handleMeteredConnection();
 }
 
 /*!
@@ -394,38 +411,30 @@ QString SyncthingConnection::substituteTilde(const QString &path) const
 }
 
 /*!
- * \brief Ensures that devices are paused/resumed depending on whether the network connection is metered.
+ * \brief Ensures that devices, discovery and relaying are enabled depending on whether suspension is enabled or the network connection is metered.
  */
-void SyncthingConnection::handleMeteredConnection()
+bool SyncthingConnection::handleMeteredConnection()
 {
+    if (!m_hasConfig || m_myId.isEmpty()) {
+        return false;
+    }
+    if (m_forceSuspend) {
+        return suspendOrResume(true);
+    }
+    if (!m_pausingOnMeteredConnection) {
+        return suspendOrResume(false);
+    }
 #ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
     const auto *const networkInformation = QNetworkInformation::instance();
-    if (!networkInformation
+    if (networkInformation
 #ifndef Q_OS_ANDROID // see comment in loadNetworkInformationBackendForMetered()
-        || !networkInformation->supports(QNetworkInformation::Feature::Metered)
+        && networkInformation->supports(QNetworkInformation::Feature::Metered)
 #endif
-        ) {
-        return;
-    }
-    if (networkInformation->isMetered() && m_pausingOnMeteredConnection) {
-        auto hasDevicesToPause = false;
-        m_devsPausedDueToMeteredConnection.reserve(static_cast<qsizetype>(m_devs.size()));
-        for (const auto &device : m_devs) {
-            if (!device.paused && device.status != SyncthingDevStatus::ThisDevice) {
-                if (!m_devsPausedDueToMeteredConnection.contains(device.id)) {
-                    m_devsPausedDueToMeteredConnection << device.id;
-                    hasDevicesToPause = true;
-                }
-            }
-        }
-        if (hasDevicesToPause) {
-            pauseResumeDevice(m_devsPausedDueToMeteredConnection, true, true);
-        }
-    } else {
-        pauseResumeDevice(m_devsPausedDueToMeteredConnection, false, true);
-        m_devsPausedDueToMeteredConnection.clear();
+    ) {
+        return suspendOrResume(networkInformation->isMetered());
     }
 #endif
+    return false;
 }
 
 /*!
@@ -435,8 +444,7 @@ void SyncthingConnection::handleMeteredConnection()
  * the connection to the currently configured instance is established. Use reconnect() to connect to
  * a different instance.
  *
- * \remarks Does not clear data from a previous connection (except error items). Use reconnect() if that
- *          is required.
+ * \remarks Does not clear data from a previous connection. Use reconnect() if that is required.
  */
 void SyncthingConnection::connect()
 {
@@ -648,7 +656,7 @@ void SyncthingConnection::continueReconnecting()
     m_dirs.swap(tempDirs);
     m_devs.swap(tempDevs);
     m_errors.clear();
-    m_devsPausedDueToMeteredConnection.clear();
+    m_suspendedItems.clear();
     m_lastConnectionsUpdateEvent = 0;
     m_lastConnectionsUpdateTime = DateTime();
     m_lastFileEvent = 0;
@@ -683,6 +691,9 @@ void SyncthingConnection::applyRawConfig()
 {
     readDevs(m_rawConfig.value(QLatin1String("devices")).toArray());
     readDirs(m_rawConfig.value(QLatin1String("folders")).toArray());
+    if (m_pausingOnMeteredConnection) {
+        handleMeteredConnection();
+    }
     emit newConfigApplied();
 }
 
@@ -1155,7 +1166,10 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
     setLongPollingTimeout(connectionSettings.longPollingTimeout);
     setDiskEventLimit(connectionSettings.diskEventLimit);
     setStatusComputionFlags(connectionSettings.statusComputionFlags);
-    setPausingOnMeteredConnection(connectionSettings.pauseOnMeteredConnection);
+    if (setForceSuspendEnabled(connectionSettings.forceSuspend, true)
+        | setPausingOnMeteredConnection(connectionSettings.pauseOnMeteredConnection, true)) {
+        handleMeteredConnection();
+    }
 
     return reconnectRequired;
 }
@@ -1477,6 +1491,94 @@ SyncthingCompletion SyncthingConnection::computeOverallRemoteCompletion() const
     return completion;
 }
 
+/*!
+ * \brief Clears all fields.
+ */
+void Data::SyncthingConnection::SuspendedItems::clear()
+{
+    devIds.clear();
+    changedOptions = QJsonObject();
+    populatedForDeviceId.clear();
+}
+
+/*!
+ * \brief Restores all fields from persistent storage for \a thisDeviceId unless already populated.
+ */
+bool SyncthingConnection::SuspendedItems::restore(const QString &thisDeviceId)
+{
+    if (populatedForDeviceId == thisDeviceId) {
+        return true;
+    }
+
+    clear();
+
+    auto file = QFile(locatePersistentFile(thisDeviceId));
+    auto jsonParseError = QJsonParseError();
+    if (!file.open(QFile::ReadOnly)) {
+        return false;
+    }
+    const auto jsonData = file.readAll();
+    if (!file.error() == QFile::NoError) {
+        return false;
+    }
+    const auto jsonDoc = QJsonDocument::fromJson(jsonData, &jsonParseError);
+    if (jsonParseError.error != QJsonParseError::NoError) {
+        return false;
+    }
+    const auto jsonObj = jsonDoc.object();
+    const auto devIdsArray = jsonObj.value(QStringLiteral("devIds")).toArray();
+    devIds.reserve(devIdsArray.size());
+    for (const auto &devId : devIdsArray) {
+        devIds.append(devId.toString());
+    }
+    changedOptions = jsonObj.value(QStringLiteral("changedOptions")).toObject();
+    populatedForDeviceId = thisDeviceId;
+    return true;
+}
+
+/*!
+ * \brief Saves all fields to persistent storage.
+ */
+bool SyncthingConnection::SuspendedItems::save()
+{
+    if (populatedForDeviceId.isEmpty()) {
+        return false;
+    }
+    auto file = QFile(locatePersistentFile(populatedForDeviceId));
+    if (devIds.isEmpty() && changedOptions.isEmpty()) {
+        return file.remove() || !file.exists();
+    }
+    if (!file.open(QFile::WriteOnly | QFile::Truncate)) {
+        return false;
+    }
+    auto jsonObj = QJsonObject();
+    jsonObj.insert(QStringLiteral("devIds"), QJsonArray::fromStringList(devIds));
+    jsonObj.insert(QStringLiteral("changedOptions"), changedOptions);
+    file.write(QJsonDocument(jsonObj).toJson());
+    if (file.error() == QFile::NoError) {
+        file.flush();
+    }
+    return file.error() == QFile::NoError;
+}
+
+/*!
+ * \brief Locates the file for \a thisDeviceId in persistent storage.
+ */
+QString SyncthingConnection::SuspendedItems::locatePersistentFile(const QString &thisDeviceId)
+{
+    if (!m_persistentDir.has_value()) {
+        static const auto subDir = QStringLiteral("/suspended-items");
+        const auto pathFromEnv = qEnvironmentVariable(PROJECT_VARNAME_UPPER "_LOCAL_DATA_DIR");
+        if (!pathFromEnv.isEmpty()) {
+            m_persistentDir.emplace(pathFromEnv + subDir);
+        } else {
+            m_persistentDir.emplace(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + subDir);
+        }
+    }
+    m_persistentDir->mkpath(QStringLiteral("."));
+    return m_persistentDir->path() % QChar('/') % thisDeviceId % QStringLiteral(".json");
+}
+
 /*!
  * \fn SyncthingConnection::newConfig()
  * \brief Indicates new configuration (dirs, devs, ...) is available.
