@@ -1,14 +1,11 @@
 #include "./syncthingprocess.h"
 #include "./syncthingconnection.h"
 
+#include <QCoreApplication>
 #include <QEventLoop>
 #include <QStringBuilder>
 #include <QTimer>
 
-#ifdef Q_OS_WINDOWS
-#include <QCoreApplication>
-#endif
-
 // uncomment to enforce stopSyncthing() via REST-API (for testing)
 //#define LIB_SYNCTHING_CONNECTOR_ENFORCE_STOP_VIA_API
 
@@ -238,6 +235,27 @@ QStringList SyncthingProcess::splitArguments(const QString &arguments)
     return result;
 }
 
+/*!
+ * \brief Returns a generic error string for \a error.
+ */
+QString SyncthingProcess::genericErrorString(QProcess::ProcessError error)
+{
+    switch (error) {
+    case QProcess::FailedToStart:
+        return tr("failed to start (e.g. executable does not exist or not permission error)");
+    case QProcess::Crashed:
+        return tr("process crashed");
+    case QProcess::Timedout:
+        return tr("timeout error");
+    case QProcess::ReadError:
+        return tr("read error");
+    case QProcess::WriteError:
+        return tr("write error");
+    default:
+        return tr("unknown process error");
+    }
+}
+
 /*!
  * \brief Emits errorOccurred() as if the specified \a error had occurred and sets the specified \a errorString.
  * \remarks May be called if a precondition for starting the process (that is checked outside of the SyncthingProcess
@@ -502,13 +520,14 @@ void SyncthingProcess::start(const QStringList &programs, const QStringList &arg
         handleLeftoverProcesses();
         emit stateChanged(m_process->state = QProcess::NotRunning);
         emit finished(rc, rc != 0 ? QProcess::CrashExit : QProcess::NormalExit);
-        if (ec) {
-            const auto msg = ec.message();
-            std::cerr << EscapeCodes::Phrases::Info << "Launched process " << m_process->child.native_handle() << " exited with error: " << msg
-                      << EscapeCodes::Phrases::End;
-            QMetaObject::invokeMethod(this, "handleError", Qt::QueuedConnection, Q_ARG(int, QProcess::Crashed),
-                Q_ARG(QString, QString::fromStdString(msg)), Q_ARG(bool, false));
+        if (!ec || ec == std::errc::no_such_process || ec == std::errc::no_child_process) {
+            return;
         }
+        const auto msg = ec.message();
+        std::cerr << EscapeCodes::Phrases::Info << "Launched process " << m_process->child.native_handle() << " exited with error: " << msg
+                  << EscapeCodes::Phrases::End;
+        QMetaObject::invokeMethod(this, "handleError", Qt::QueuedConnection, Q_ARG(int, QProcess::Crashed),
+            Q_ARG(QString, QString::fromStdString(msg)), Q_ARG(bool, false));
     };
     auto errorHandler = boost::process::v1::extend::on_error = [this, maybeProcess = m_process->weak_from_this()](auto &, const std::error_code &ec) {
         const auto overallProcessLock = std::lock_guard<std::mutex>(m_processMutex);
@@ -554,7 +573,21 @@ void SyncthingProcess::start(const QStringList &programs, const QStringList &arg
         }
         hasProgram = true;
         if (path.is_relative()) {
-            path = boost::process::v1::search_path(path);
+            static const auto searchPaths = [] {
+                auto paths = ::boost::this_process::path();
+                if (const auto appDir = QCoreApplication::applicationDirPath(); !appDir.isEmpty()) {
+                    // fallback to app dir like it is done when locating settings and translations
+                    // note: This is mostly useful under Windows where one might store `syncthingtray.exe` and `syncthing.exe` in
+                    //       the same directory and the lookup is expected to work even if a different working directory is used.
+                    // note: This fallback is *not* present when QProcess is used as it does not seem to allow appending additional
+                    //       search paths easily. One would have to implement functions like `boost::this_process::path()` and
+                    //       `boost::process::v1::search_path()` manually and supply an absolute path. This is not worth is
+                    //       considering Boost.Process is favourable anyway.
+                    paths.emplace_back(LIB_SYNCTHING_CONNECTOR_STRING_CONVERSION(appDir));
+                }
+                return paths;
+            }();
+            path = boost::process::v1::search_path(path, searchPaths);
         }
         if (!path.empty()) {
             break;
